# Useful libraries

- [pyo3](https://github.com/PyO3/pyo3) - Generer swaggy rust bindings for python
- [ndarray](https://docs.rs/ndarray/0.15.6/ndarray/index.html) - lineær algebra som er bra for store arrays
- [rust-numpy](https://github.com/PyO3/rust-numpy) - numpy typer
- [nalgebra](https://docs.rs/nalgebra/latest/nalgebra/) - lineær algebra, glam er raskere
- [LAPACK](https://docs.rs/lapack/latest/lapack/) - fortran wrappers LAPACK
- [glam](https://docs.rs/glam/) - vektorer og matriser, ment for vektorer på 1-4 elementer.
- [BLAS](https://crates.io/crates/blas) - Det mest populære blas biblioteket.